mapcalc.lad <- function (estimable, nfac, nruns, res3 = FALSE, select.catlg = catlg, 
    sort = "natural", method="LAD") 
{
    ## function graph.subisomorphic.lad is part of version 7 of package igraph
    ## it has been used in an early implementation provided by Gabor Csardi
    ## ()
    if (ncol(estimable) > nruns - nfac - 1) 
        stop("too many interactions requested for this number of runs and factors")
    if (nruns > 32 & res3) {
        warning("res3=TRUE has no effect for designs with more than 32 runs.")
        res3 <- FALSE
    }
    catlg <- select.catlg
    go2 <- graph.empty(n = nfac, directed = FALSE)
    go2 <- add.edges(go2, estimable)
    deg2 <- degree(go2)
    if (sort %in% c("high", "low")) {
        if (sort == "low") 
            ord2 <- order(deg2)
        else ord2 <- order(deg2, decreasing = TRUE)
        go2 <- permute.vertices(go2, FrF2:::invperm(ord2))
    }
    degree2 <- rev(cumsum(rev(table(deg2))))
    degs2 <- as.numeric(names(degree2))
    indep2 <- independence.number(go2)
    clique2 <- clique.number(go2)
    tobechecked <- catlg[which(nfac(catlg) == nfac & nruns(catlg) == 
        nruns & dominating(catlg))]
    if (length(tobechecked) > 0) 
        if (!res3) 
            tobechecked <- tobechecked[which(res(tobechecked) >= 
                4)]
    if (length(tobechecked) > 0) 
        tobechecked <- tobechecked[which(nclear.2fis(tobechecked) >= 
            ncol(estimable))]
    if (length(tobechecked) == 0) 
        if (res3) 
            stop("The required interactions cannot be accomodated clear of aliasing in ", 
                nruns, " runs.")
        else {
            if (nruns <= 64) 
                stop("The required interactions cannot be accomodated clear of aliasing in ", 
                  nruns, " runs with resolution IV or higher.")
            else stop("No resolution IV or higher design from the current catalogue can accomodate the required interactions clear of aliasing in ", 
                nruns, " runs.")
        }
    map <- NULL
    for (i in 1:length(tobechecked)) {
        assign(".FrF2.currentlychecked", names(tobechecked[i]), 
            envir = .GlobalEnv)
        go1 <- graph.empty(n = nfac, directed = FALSE)
        go1 <- add.edges(go1, tobechecked[[i]]$clear.2fis)
        deg1 <- degree(go1)
        if (sort %in% c("high", "low")) {
            if (sort == "low") 
                ord1 <- order(deg1)
            else ord1 <- order(deg1, decreasing = TRUE)
            go1 <- permute.vertices(go1, FrF2:::invperm(ord1))
        }
        degree1 <- rev(cumsum(rev(table(deg1))))
        degs1 <- as.numeric(names(degree1))
        if (max(degs2) <= max(degs1)) {
            comp <- sapply(degs2, function(obj) degree1[min(which(degs1 >= 
                obj))])
            comp[is.na(comp)] <- 0
            if (any(comp < degree2)) 
                next
            if (independence.number(go1) > indep2) 
                next
            if (clique.number(go1) < clique2) 
                next
            if (method=="LAD") 
            erg <- graph.subisomorphic.lad(go2, go1)
            else erg <- graph.subisomorphic.vf2(go1, go2)
            if (erg$iso) {
                if (method=="LAD") map <- list(erg$map)
                else map <- list(erg$map21)
                if (sort %in% c("high", "low")) 
                  map <- list(ord1[map[[1]]][FrF2:::invperm(ord2)])
                names(map) <- get(".FrF2.currentlychecked")
                rm(.FrF2.currentlychecked, envir = .GlobalEnv)
                break
            }
        }
    }
    if (is.null(map)) 
        if (res3) 
            stop("The required interactions cannot be accomodated clear of aliasing in ", 
                nruns, " runs.")
        else {
            if (nruns <= 64) 
                stop("The required interactions cannot be accomodated clear of aliasing in ", 
                  nruns, " runs with resolution IV or higher.")
            else stop("No resolution IV or higher design from the current catalogue can accomodate the required interactions clear of aliasing in ", 
                nruns, " runs.")
        }
    map
}
